@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,8 @@
 #include <libexplain/ac/getopt.h>
 
 #include <libexplain/errno_info.h>
+#include <libexplain/errno_info/print.h>
+#include <libexplain/exit.h>
 #include <libexplain/freopen.h>
 #include <libexplain/iocontrol.h>
 #include <libexplain/string_buffer.h>
@@ -45,9 +47,11 @@ usage(void)
 static const struct option options[] =
 {
     { "errno", 1, 0, 'e' },
+    { "explain-exit-status", 0, 0, 'E' },
     { "message", 1, 0, 'm' },
-    { "version", 0, 0, 'V' },
+    { "print-errno-info", 0, 0, 'P' },
     { "statistics", 0, 0, 's' },
+    { "version", 0, 0, 'V' },
     { "check-ioctl-conflicts", 0, 0, 'Z' },
     { 0, 0, 0, 0 }
 };
@@ -111,7 +115,11 @@ figure_out_error(const char *text)
             &sb,
             " doesn't match any known symbol, guessing you meant "
         );
-        explain_string_buffer_puts_quoted(&sb, strerror(eip->error_number));
+        explain_string_buffer_puts_quoted
+        (
+            &sb,
+            explain_internal_strerror(eip->error_number)
+        );
         explain_string_buffer_puts(&sb, " instead");
         explain_wrap_and_print(stderr, message);
         exit_status = EXIT_FAILURE;
@@ -160,11 +168,15 @@ main(int argc, char **argv)
     err = -1;
     for (;;)
     {
-        int c = getopt_long(argc, argv, "e:o:sVZ", options, 0);
+        int c = getopt_long(argc, argv, "Ee:o:PpsVZ", options, 0);
         if (c == EOF)
             break;
         switch (c)
         {
+        case 'E':
+            explain_exit_on_exit();
+            break;
+
         case 'e':
             err = figure_out_error(optarg);
             break;
@@ -173,6 +185,14 @@ main(int argc, char **argv)
             explain_freopen_or_die(optarg, "w", stdout);
             break;
 
+        case 'p':
+            explain_errno_info_print(0);
+            return 0;
+
+        case 'P':
+            explain_errno_info_print(1);
+            return 0;
+
         case 's':
             print_statistics();
             return 0;
