@@ -107,6 +107,8 @@
 #include <explain/syscall/mkostemp.h>
 #include <explain/syscall/mkstemp.h>
 #include <explain/syscall/mktemp.h>
+#include <explain/syscall/mmap.h>
+#include <explain/syscall/munmap.h>
 #include <explain/syscall/nice.h>
 #include <explain/syscall/opendir.h>
 #include <explain/syscall/open.h>
@@ -177,6 +179,7 @@
 #include <explain/syscall/unsetenv.h>
 #include <explain/syscall/ustat.h>
 #include <explain/syscall/utime.h>
+#include <explain/syscall/utimes.h>
 #include <explain/syscall/vfork.h>
 #include <explain/syscall/wait.h>
 #include <explain/syscall/wait3.h>
@@ -376,7 +379,7 @@ static const table_t table[] =
     { "mktemp", explain_syscall_mktemp },
     /* FIXME: add support for mlock */
     /* FIXME: add support for mlockall */
-    /* FIXME: add support for mmap */
+    { "mmap", explain_syscall_mmap },
     /* FIXME: add support for mmap2 */
     /* FIXME: add support for modify_ldt */
     /* FIXME: add support for mount */
@@ -397,7 +400,7 @@ static const table_t table[] =
     /* FIXME: add support for msync */
     /* FIXME: add support for munlock */
     /* FIXME: add support for munlockall */
-    /* FIXME: add support for munmap */
+    { "munmap", explain_syscall_munmap },
     /* ----------  N  ------------------------------------------------------- */
     /* FIXME: add support for nanosleep */
     /* FIXME: add support for nfsservctl */
@@ -602,7 +605,7 @@ static const table_t table[] =
     { "ustat", explain_syscall_ustat },
     { "utime", explain_syscall_utime },
     /* FIXME: add support for utimens */
-    /* FIXME: add support for utimes */
+    { "utimes", explain_syscall_utimes },
     /* ----------  V  ------------------------------------------------------- */
     { "vfork", explain_syscall_vfork },
     /* FIXME: add support for vfscanf */
