@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
 #include <libexplain/ac/string.h>
+#include <libexplain/ac/sys/mtio.h>
 
 #include <libexplain/iocontrol.h>
 #include <libexplain/ioctl.h>
@@ -54,6 +55,13 @@ explain_syscall_ioctl(int errnum, int argc, char **argv)
         exit(EXIT_FAILURE);
     }
 
+#ifdef MTIOCTOP
+    if (request == (int)MTIOCTOP && data == dummy_data)
+    {
+        struct mtop *p = data;
+        p->mt_op = MTFSF;
+    }
+#endif
     explain_wrap_and_print
     (
         stdout,
