@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -38,9 +38,9 @@ explain_buffer_errno_fputc_system_call(explain_string_buffer_t *sb,
 }
 
 
-static void
+void
 explain_buffer_errno_fputc_explanation(explain_string_buffer_t *sb,
-    int errnum, int c, FILE *fp)
+    int errnum, const char *syscall_name, int c, FILE *fp)
 {
     int             fildes;
 
@@ -53,7 +53,7 @@ explain_buffer_errno_fputc_explanation(explain_string_buffer_t *sb,
     (
         sb,
         errnum,
-        "fputc",
+        syscall_name,
         fildes,
         NULL,
         0
@@ -79,6 +79,7 @@ explain_buffer_errno_fputc(explain_string_buffer_t *sb, int errnum, int c,
     (
         &exp.explanation_sb,
         errnum,
+        "fputc",
         c,
         fp
     );
