@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,7 @@
 #include <libexplain/buffer/enametoolong.h>
 #include <libexplain/buffer/enoent.h>
 #include <libexplain/buffer/enomem.h>
+#include <libexplain/buffer/enospc.h>
 #include <libexplain/buffer/enotdir.h>
 #include <libexplain/buffer/erofs.h>
 #include <libexplain/buffer/errno/link.h>
@@ -36,6 +37,7 @@
 #include <libexplain/buffer/errno/path_resolution.h>
 #include <libexplain/buffer/exdev.h>
 #include <libexplain/buffer/mount_point.h>
+#include <libexplain/buffer/note/still_exists.h>
 #include <libexplain/buffer/pathname.h>
 #include <libexplain/dirname.h>
 #include <libexplain/explanation.h>
@@ -188,17 +190,7 @@ explain_buffer_errno_link_explanation(explain_string_buffer_t *sb,
         break;
 
     case ENOSPC:
-        explain_string_buffer_puts
-        (
-            sb,
-            "the file system containing newpath"
-        );
-        explain_buffer_mount_point_dirname(sb, newpath);
-        explain_string_buffer_puts
-        (
-            sb,
-            " has no room for the new directory entry"
-        );
+        explain_buffer_enospc(sb, newpath, "newpath");
         break;
 
     case ENOTDIR:
@@ -273,18 +265,7 @@ explain_buffer_errno_link_explanation(explain_string_buffer_t *sb,
     /*
      * Let the user know where things stand after the failure.
      */
-    {
-        struct stat st;
-        if (lstat(newpath, &st) == 0)
-        {
-            explain_string_buffer_puts
-            (
-                sb,
-                "; note that newpath exists"
-            );
-        }
-    }
-
+    explain_buffer_note_if_exists(sb, newpath, "newpath");
 }
 
 
