@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,24 +39,25 @@
 
 static void
 explain_buffer_errno_lstat_system_call(explain_string_buffer_t *sb,
-    int errnum, const char *pathname, const struct stat *buf)
+    int errnum, const char *pathname, const struct stat *data)
 {
     (void)errnum;
     explain_string_buffer_printf(sb, "lstat(pathname = ");
     explain_buffer_pathname(sb, pathname);
-    explain_string_buffer_puts(sb, ", buf = ");
-    explain_buffer_pointer(sb, buf);
+    explain_string_buffer_puts(sb, ", data = ");
+    explain_buffer_pointer(sb, data);
     explain_string_buffer_putc(sb, ')');
 }
 
 
-static void
+void
 explain_buffer_errno_lstat_explanation(explain_string_buffer_t *sb,
-    int errnum, const char *pathname, const struct stat *buf)
+    int errnum, const char *syscall_name, const char *pathname,
+    const struct stat *data)
 {
     explain_final_t final_component;
 
-    (void)buf;
+    (void)data;
     explain_final_init(&final_component);
     final_component.follow_symlink = 0;
 
@@ -72,9 +73,9 @@ explain_buffer_errno_lstat_explanation(explain_string_buffer_t *sb,
             explain_buffer_efault(sb, "pathname");
             break;
         }
-        if (explain_pointer_is_efault(buf, sizeof(*buf)))
+        if (explain_pointer_is_efault(data, sizeof(*data)))
         {
-            explain_buffer_efault(sb, "buf");
+            explain_buffer_efault(sb, "data");
             break;
         }
         break;
@@ -107,7 +108,7 @@ explain_buffer_errno_lstat_explanation(explain_string_buffer_t *sb,
         break;
 
     default:
-        explain_buffer_errno_generic(sb, errnum, "lstat");
+        explain_buffer_errno_generic(sb, errnum, syscall_name);
         break;
     }
 }
@@ -115,7 +116,7 @@ explain_buffer_errno_lstat_explanation(explain_string_buffer_t *sb,
 
 void
 explain_buffer_errno_lstat(explain_string_buffer_t *sb, int errnum,
-    const char *pathname, const struct stat *buf)
+    const char *pathname, const struct stat *data)
 {
     explain_explanation_t exp;
 
@@ -125,14 +126,15 @@ explain_buffer_errno_lstat(explain_string_buffer_t *sb, int errnum,
         &exp.system_call_sb,
         errnum,
         pathname,
-        buf
+        data
     );
     explain_buffer_errno_lstat_explanation
     (
         &exp.explanation_sb,
         errnum,
+        "lstat",
         pathname,
-        buf
+        data
     );
     explain_explanation_assemble(&exp, sb);
 }
