@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,8 @@
 #include <libexplain/ac/assert.h>
 #include <libexplain/ac/errno.h>
 #include <libexplain/ac/fcntl.h>
-#include <libexplain/ac/sys/stat.h>
+#include <libexplain/ac/sys/sysmacros.h> /* major()/minor() on Solaris */
+#include <libexplain/ac/sys/stat.h> /* major()/minor() every where else */
 #include <libexplain/ac/unistd.h>
 
 #include <libexplain/buffer/dac.h>
@@ -30,11 +31,12 @@
 #include <libexplain/buffer/eisdir.h>
 #include <libexplain/buffer/eloop.h>
 #include <libexplain/buffer/emfile.h>
-#include <libexplain/buffer/enfile.h>
 #include <libexplain/buffer/enametoolong.h>
+#include <libexplain/buffer/enfile.h>
 #include <libexplain/buffer/enoent.h>
 #include <libexplain/buffer/enomedium.h>
 #include <libexplain/buffer/enomem.h>
+#include <libexplain/buffer/enospc.h>
 #include <libexplain/buffer/enotdir.h>
 #include <libexplain/buffer/erofs.h>
 #include <libexplain/buffer/errno/generic.h>
@@ -45,6 +47,7 @@
 #include <libexplain/buffer/gettext.h>
 #include <libexplain/buffer/mount_point.h>
 #include <libexplain/buffer/path_to_pid.h>
+#include <libexplain/buffer/permission_mode.h>
 #include <libexplain/buffer/pointer.h>
 #include <libexplain/buffer/pretty_size.h>
 #include <libexplain/buffer/uid.h>
@@ -52,7 +55,6 @@
 #include <libexplain/explanation.h>
 #include <libexplain/open_flags.h>
 #include <libexplain/option.h>
-#include <libexplain/permission_mode.h>
 #include <libexplain/string_buffer.h>
 
 
@@ -110,9 +112,9 @@ no_corresponding_device(explain_string_buffer_t *sb, const struct stat *st)
     explain_string_buffer_printf
     (
         &numbers_sb,
-        "(%d, %d)",
-        major(st->st_dev),
-        minor(st->st_dev)
+        "(%ld, %ld)",
+        (long)major(st->st_dev),
+        (long)minor(st->st_dev)
     );
     explain_string_buffer_printf_gettext
     (
@@ -404,32 +406,7 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
         break;
 
     case ENOSPC:
-        {
-            char            mntpt[100];
-            explain_string_buffer_t mntpt_sb;
-
-            explain_string_buffer_init(&mntpt_sb, mntpt, sizeof(mntpt));
-            explain_buffer_mount_point_dirname(&mntpt_sb, pathname);
-            explain_string_buffer_printf_gettext
-            (
-                sb,
-                /*
-                 * xgettext: This message is used to provide an
-                 * explanation for and ENOSPC error returned by an
-                 * open(2) system call, in the case where there is no
-                 * more room for a new file.
-                 *
-                 * %1$s => The name of the problematic system call argument
-                 * %2$s => The file system mount point and usage,
-                 *         in parentheses
-                 */
-                i18n("the file system containing %s %s has no "
-                    "room for the new file"),
-                "pathname",
-                mntpt
-            );
-            /* FIXME: has no blocks left or has no inodes left? */
-        }
+        explain_buffer_enospc(sb, pathname, "pathname");
         break;
 
     case ENOTDIR:
@@ -522,7 +499,7 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
                 /*
                  * xgettext: This message is used when an EPERM erro is
                  * returned by an open(2) system call, and the O_NOATIME
-                 * open flag was specific, but the process lacked the
+                 * open flag was specified, but the process lacked the
                  * permissions required.
                  *
                  * %1$s => the number and name of the process effective UID,
@@ -597,10 +574,10 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
 #ifdef __linux__
                     if (explain_option_dialect_specific())
                     {
-                        explain_string_buffer_puts(sb, "; ");
+                        explain_string_buffer_puts(sb->footnotes, "; ");
                         explain_buffer_gettext
                         (
-                            sb,
+                            sb->footnotes,
                             /*
                              * xgettext: This message is used to explain an
                              * ENODEV error reported by an open(2) system
@@ -634,10 +611,10 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
     {
         if ((flags & O_ACCMODE) == O_RDONLY)
         {
-            explain_string_buffer_puts(sb, "; ");
+            explain_string_buffer_puts(sb->footnotes, "; ");
             explain_buffer_gettext
             (
-                sb,
+                sb->footnotes,
                 /*
                  * xgettext: This message is used to supplement an explanation
                  * for an error reported by open(2) system call, in the case
@@ -670,10 +647,10 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
                 case S_IFIFO:
                     /* explicitly ignored */
                     {
-                        explain_string_buffer_puts(sb, "; ");
+                        explain_string_buffer_puts(sb->footnotes, "; ");
                         explain_string_buffer_printf_gettext
                         (
-                            sb,
+                            sb->footnotes,
                             /*
                              * xgettext: This message is used to supplement an
                              * explanation for an error reported by open(2)
@@ -707,10 +684,10 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
 #endif
                     /* explicitly undefined */
                     {
-                        explain_string_buffer_puts(sb, "; ");
+                        explain_string_buffer_puts(sb->footnotes, "; ");
                         explain_string_buffer_printf_gettext
                         (
-                            sb,
+                            sb->footnotes,
                             /*
                              * xgettext: This message is used to supplement an
                              * explanation for an error reported by open(2)
@@ -734,11 +711,11 @@ explain_buffer_errno_open_explanation(explain_string_buffer_t *sb,
 
     if ((flags & O_EXCL) && !(flags & O_CREAT))
     {
-        explain_string_buffer_puts(sb, "; ");
+        explain_string_buffer_puts(sb->footnotes, "; ");
         /* FIXME: except for a TTY, where it means single open */
         explain_buffer_gettext
         (
-            sb,
+            sb->footnotes,
             /*
              * xgettext: This message is used to supplement an explanation for
              * an error reported by open(2) system call, and the caller used a
