@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,14 +17,15 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/ctype.h>
 #include <libexplain/ac/assert.h>
+#include <libexplain/ac/ctype.h>
 #include <libexplain/ac/dirent.h>
 #include <libexplain/ac/errno.h>
 #include <libexplain/ac/fcntl.h>
+#include <libexplain/ac/limits.h> /* for PATH_MAX on Solaris */
 #include <libexplain/ac/stdlib.h>
 #include <libexplain/ac/string.h>
-#include <libexplain/ac/sys/param.h>
+#include <libexplain/ac/sys/param.h> /* for PATH_MAX except Solaris */
 #include <libexplain/ac/sys/stat.h>
 #include <libexplain/ac/unistd.h>
 
@@ -42,6 +43,7 @@
 #include <libexplain/fstrcmp.h>
 #include <libexplain/getppcwd.h>
 #include <libexplain/have_permission.h>
+#include <libexplain/name_max.h>
 #include <libexplain/option.h>
 #include <libexplain/symloopmax.h>
 
@@ -88,7 +90,12 @@ look_for_similar(explain_string_buffer_t *sb, const char *lookup_directory,
         if (best_weight < weight)
         {
             best_weight = weight;
-            strendcpy(best_name, dep->d_name, best_name + sizeof(best_name));
+            explain_strendcpy
+            (
+                best_name,
+                dep->d_name,
+                best_name + sizeof(best_name)
+            );
         }
     }
     closedir(dp);
@@ -108,9 +115,9 @@ look_for_similar(explain_string_buffer_t *sb, const char *lookup_directory,
 
         ipath_end = ipath + sizeof(ipath);
         ip = ipath;
-        ip = strendcpy(ip, lookup_directory, ipath_end);
-        ip = strendcpy(ip, "/", ipath_end);
-        ip = strendcpy(ip, best_name, ipath_end);
+        ip = explain_strendcpy(ip, lookup_directory, ipath_end);
+        ip = explain_strendcpy(ip, "/", ipath_end);
+        ip = explain_strendcpy(ip, best_name, ipath_end);
         if (lstat(ipath, &st) == 0)
             st_mode = st.st_mode;
     }
@@ -907,7 +914,7 @@ explain_sticky_bit_vs_unlink(explain_string_buffer_t *sb,
     explain_buffer_uid(&file_part_sb, file_st->st_uid);
     explain_buffer_file_type(&ftype_sb, file_st->st_mode);
 
-    explain_string_buffer_puts(sb, "; ");
+    explain_string_buffer_puts(sb, ", ");
     explain_string_buffer_printf_gettext
     (
         sb,
@@ -994,9 +1001,15 @@ explain_buffer_errno_path_resolution(explain_string_buffer_t *sb,
      * In the original Unix, the empty pathname referred to the current
      * directory.  Nowadays POSIX decrees that an empty pathname must
      * not be resolved successfully.  Linux returns ENOENT in this case.
+     *
+     * FIXME: is there a way pathconf can tell us which semanrics apply?
+     *        or maybe sysconf?
      */
     if (!initial_pathname || !*initial_pathname)
     {
+#ifdef __sun__
+        initial_pathname = ".";
+#else
         explain_string_buffer_printf
         (
             sb,
@@ -1011,6 +1024,7 @@ explain_buffer_errno_path_resolution(explain_string_buffer_t *sb,
             caption
         );
         return 0;
+#endif
     }
 
     /*
