@@ -37,7 +37,6 @@
 #include <libexplain/buffer/size_t.h>
 #include <libexplain/explanation.h>
 #include <libexplain/is_same_inode.h>
-#include <libexplain/open_flags.h>
 #include <libexplain/string_buffer.h>
 
 
@@ -93,20 +92,7 @@ explain_buffer_errno_read_explanation(explain_string_buffer_t *sb, int errnum,
             flags = fcntl(fildes, F_GETFL);
             if (flags >= 0)
             {
-                explain_buffer_gettext
-                (
-                    sb,
-                    /*
-                     * xgettext: This message is used when an attempt is
-                     * made to read from a file descriptor that was not
-                     * opened for reading.  The actual open mode will be
-                     * printed separately.
-                     */
-                    i18n("the file descriptor is not open for reading")
-                );
-                explain_string_buffer_puts(sb, " (");
-                explain_buffer_open_flags(sb, flags);
-                explain_string_buffer_putc(sb, ')');
+                explain_buffer_ebadf_not_open_for_reading(sb, flags);
             }
             else
             {
@@ -132,15 +118,7 @@ explain_buffer_errno_read_explanation(explain_string_buffer_t *sb, int errnum,
             {
                 if ((flags & O_ACCMODE) == O_WRONLY)
                 {
-                    explain_string_buffer_puts
-                    (
-                        sb,
-                        /* FIXME: i18n */
-                        "the file descriptor is attached to an object "
-                        "which is unsuitable for reading ("
-                    );
-                    explain_buffer_open_flags(sb, flags);
-                    explain_string_buffer_putc(sb, ')');
+                    explain_buffer_ebadf_not_open_for_reading(sb, flags);
                 }
 #ifdef O_DIRECT
                 else if (flags & O_DIRECT)
@@ -220,10 +198,9 @@ explain_buffer_errno_read_explanation(explain_string_buffer_t *sb, int errnum,
                     (
                         sb,
                         /* FIXME: i18n */
-                        "the process is in a background "
-                        "process group, and tried to read from its "
-                        "controlling tty, and either it is ignoring or "
-                        "blocking SIGTTIN"
+                        "the process is in a background process group, and "
+                        "tried to read from its controlling tty, and the "
+                        "controlling tty is either ignoring or blocking SIGTTIN"
                     );
                     close(controlling_tty_fd);
                     break;
