@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,9 @@
 #include <libexplain/buffer/enametoolong.h>
 #include <libexplain/buffer/enoent.h>
 #include <libexplain/buffer/enomem.h>
+#include <libexplain/buffer/enospc.h>
 #include <libexplain/buffer/enotdir.h>
+#include <libexplain/buffer/eperm.h>
 #include <libexplain/buffer/erofs.h>
 #include <libexplain/buffer/errno/generic.h>
 #include <libexplain/buffer/errno/path_resolution.h>
@@ -150,10 +152,22 @@ explain_buffer_errno_rename_explanation(explain_string_buffer_t *sb,
     case EACCES:
         /*
          * Check specific requirements for renaming directories.
+         *
+         * Note that this is not the case for Solaris.
+         *
+         * FIXME: how do we ask pathconf if we need this test?
+         * It is possible that this next test does not apply for any file
+         * system that does not actually store "." and/or ".." in the
+         * directory data, but generates them at getdent/readdir time.
          */
+#ifndef __sun__
         {
             struct stat     oldpath_st;
 
+            /*
+             * See if we have write permission on the oldpath containing
+             * directory, so that we can update st_nlink for "."
+             */
             if
             (
                 stat(oldpath, &oldpath_st) >= 0
@@ -187,6 +201,7 @@ explain_buffer_errno_rename_explanation(explain_string_buffer_t *sb,
                 break;
             }
         }
+#endif
 
         /*
          * Check the paths themselves
@@ -353,21 +368,7 @@ explain_buffer_errno_rename_explanation(explain_string_buffer_t *sb,
         break;
 
     case ENOSPC:
-        explain_buffer_gettext
-        (
-            sb,
-            /*
-             * xgettext: This message is used to explain an ENOSPC error
-             * reported by a rename(2) system call.
-             *
-             * It may optionally be followed by the actual mount point,
-             * so it helps if the sentance structure works for that
-             * case.
-             */
-            i18n("the file system containing the file has no room for "
-            "the new directory entry")
-        );
-        explain_buffer_mount_point(sb, oldpath);
+        explain_buffer_enospc(sb, newpath, "newpath");
         break;
 
     case ENOTDIR:
@@ -448,84 +449,10 @@ explain_buffer_errno_rename_explanation(explain_string_buffer_t *sb,
             )
         )
         {
-            explain_string_buffer_printf_gettext
-            (
-                sb,
-                /*
-                 * xgettext: This message is used to EPERM error reported by
-                 * a rename(2) system call, in the case where the directory
-                 * containing oldpath has the sticky bit (S_ISVTX) set and the
-                 * process's effective user ID is neither the user ID of the
-                 * file to be deleted nor that of the directory containing it,
-                 * and the process is not privileged.
-                 *
-                 * %1$s => the name of the offending system call argument
-                 */
-                i18n("the directory containing %s has the sticky bit "
-                    "(S_ISVTX) set and the process's effective user ID is "
-                    "neither the user ID of the file to be deleted nor that "
-                    "of the directory containing it, and the process is not "
-                    "privileged"),
-                "oldpath"
-            );
-#ifdef HAVE_SYS_CAPABILITY_H
-            if (explain_option_dialect_specific())
-            {
-                explain_string_buffer_puts
-                (
-                    sb,
-                    " (does not have the CAP_FOWNER capability)"
-                );
-            }
-#endif
-            explain_string_buffer_puts(sb, "; ");
-            explain_string_buffer_printf_gettext
-            (
-                sb,
-                /*
-                 * xgettext: This message is used to EPERM error
-                 * reported by a rename(2) system call, in the case
-                 * where newpath is an existing file and the directory
-                 * containing it has the sticky bit set and the
-                 * process's effective user ID is neither the user ID
-                 * of the file to be replaced nor that of the directory
-                 * containing it, and the process is not privileged.
-                 *
-                 * %1$s => the name of the offending system call argument
-                 */
-                i18n("or %s is an existing file and the directory "
-                    "containing it has the sticky bit set and the "
-                    "process's effective user ID is neither the user ID "
-                    "of the file to be replaced nor that of the directory "
-                    "containing it, and the process is not privileged"),
-                "newpath"
-            );
-#ifdef HAVE_SYS_CAPABILITY_H
-            if (explain_option_dialect_specific())
-            {
-                explain_string_buffer_puts
-                (
-                    sb,
-                    " (does not have the CAP_FOWNER capability)"
-                );
-            }
-#endif
-            explain_string_buffer_puts(sb, "; ");
-            explain_string_buffer_printf_gettext
-            (
-                sb,
-                /*
-                 * xgettext: This message is used to EPERM error reported by a
-                 * rename(2) system call, in the case where the the file system
-                 * containing pathname does not support renaming of the type
-                 * requested.
-                 *
-                 * %1$s => the name of the offending system call argument
-                 */
-                i18n("or the file system containing %s does not "
-                    "support renaming of the type requested"),
-                "newpath"
-            );
+            /* FIXME: this needs to be much more specific */
+            explain_buffer_eperm_unlink(sb, oldpath, "oldpath", syscall_name);
+            explain_string_buffer_puts(sb, "; or, ");
+            explain_buffer_eperm_unlink(sb, newpath, "newpath", syscall_name);
         }
         break;
 
