@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
@@ -36,28 +36,14 @@ explain_buffer_uint(explain_string_buffer_t *sb, unsigned data)
 
 
 void
-explain_buffer_int_star(explain_string_buffer_t *sb, const int *data)
+explain_buffer_uint_star(explain_string_buffer_t *sb, const unsigned *data)
 {
     if (explain_pointer_is_efault(data, sizeof(*data)))
         explain_buffer_pointer(sb, data);
     else
     {
         explain_string_buffer_puts(sb, "{ ");
-        explain_buffer_int(sb, *data);
-        explain_string_buffer_puts(sb, " }");
-    }
-}
-
-
-void
-explain_buffer_one_char_star(explain_string_buffer_t *sb, const char *data)
-{
-    if (explain_pointer_is_efault(data, sizeof(*data)))
-        explain_buffer_pointer(sb, data);
-    else
-    {
-        explain_string_buffer_puts(sb, "{ ");
-        explain_buffer_int(sb, *data);
+        explain_buffer_uint(sb, *data);
         explain_string_buffer_puts(sb, " }");
     }
 }
