@@ -25,7 +25,7 @@ void
 explain_buffer_string_n(explain_string_buffer_t *sb, const char *data,
     size_t data_size)
 {
-    if (explain_path_is_efault(data))
+    if (explain_pointer_is_efault(data, data_size))
         explain_buffer_pointer(sb, data);
     else
         explain_string_buffer_puts_quoted_n(sb, data, data_size);
