@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,5 +32,9 @@ explain_dir_to_fildes(DIR *dir)
      */
     if (explain_pointer_is_efault(dir, sizeof(int)))
         return -1;
+#ifdef HAVE_DIRFD
     return dirfd(dir);
+#else
+    return -1;
+#endif
 }
