@@ -21,6 +21,31 @@
 #define LIBEXPLAIN_IOCONTROL_H
 
 struct explain_string_buffer_t; /* forward */
+typedef struct explain_iocontrol_t explain_iocontrol_t;
+
+/**
+  * The expain_iocontrol_print_func_t type is used to represent a
+  * pointer to a function that prints somethign related to an ioctl
+  * request.
+  *
+  * @param p
+  *     Pointer to the explain_iocontrol_t instance,
+  *     rather like "this" in C++ code.
+  * @param sb
+  *     The string buffer to print into.
+  * @param errnum
+  *     The error number that caused all this, obtained from the
+  *     global errno variable, possibly indirectly.
+  * @param fildes
+  *     The original fildes, exactly as passed to the ioctl(2) system call.
+  * @param request
+  *     The original request, exactly as passed to the ioctl(2) system call.
+  * @param data
+  *     The original data, exactly as passed to the ioctl(2) system call.
+  */
+typedef void (*expain_iocontrol_print_func_t)(const explain_iocontrol_t *p,
+    struct explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data);
 
 /**
   * The explain_iocontrol_t type is used to represent an ioctl(2) call,
@@ -32,7 +57,6 @@ struct explain_string_buffer_t; /* forward */
   *     are ambiguous, and (b) the includes files have bugs making it
   *     impossible to include all of them in the same combilation unit.
   */
-typedef struct explain_iocontrol_t explain_iocontrol_t;
 struct explain_iocontrol_t
 {
     /**
@@ -64,76 +88,28 @@ struct explain_iocontrol_t
     int (*disambiguate)(int fildes, int request, const void *data);
 
     /**
-      * The print_name method is used to print the name of a request
-      * argument passed to an ioctl(2) system call.
+      * The print_name member is a pointer to a function that is is used
+      * to print the name of a request argument passed to an ioctl(2)
+      * system call.
       *
       * If the NULL pointer is used, the default action is to print the
       * name member.
-      *
-      * @param p
-      *     Pointer to the explain_iocontrol_t instance,
-      *     rather like "this" in C++ code.
-      * @param sb
-      *     The string buffer to print into.
-      * @param errnum
-      *     The error number that caused all this, obtained from the
-      *     global errno variable, possibly indirectly.
-      * @param fildes
-      *     The original fildes, exactly as passed to the ioctl(2) system call.
-      * @param request
-      *     The original request, exactly as passed to the ioctl(2) system call.
-      * @param data
-      *     The original data, exactly as passed to the ioctl(2) system call.
       */
-    void (*print_name)(const explain_iocontrol_t *p,
-        struct explain_string_buffer_t *sb, int errnum, int fildes,
-        int request, const void *data);
+    expain_iocontrol_print_func_t print_name;
 
     /**
-      * The print_data method is used to print a representation of the data
-      * argument passed to an ioctl(2) system call.
-      *
-      * @param p
-      *     Pointer to the explain_iocontrol_t instance,
-      *     rather like "this" in C++ code.
-      * @param sb
-      *     The string buffer to print into.
-      * @param errnum
-      *     The error number that caused all this, obtained from the
-      *     global errno variable, possibly indirectly.
-      * @param fildes
-      *     The original fildes, exactly as passed to the ioctl(2) system call.
-      * @param request
-      *     The original request, exactly as passed to the ioctl(2) system call.
-      * @param data
-      *     The original data, exactly as passed to the ioctl(2) system call.
+      * The print_data member is a pointer to a fucntion that is used
+      * to print a representation of the data argument passed to an
+      * ioctl(2) system call.
       */
-    void (*print_data)(const explain_iocontrol_t *p,
-        struct explain_string_buffer_t *sb, int errnum, int fildes,
-        int request, const void *data);
+    expain_iocontrol_print_func_t print_data;
 
     /**
-      * The print_explanation method is used to print an explanation for
-      * an error reported by an ioctl(2) system call.
-      *
-      * @param p
-      *     Pointer to the explain_iocontrol_t instance,
-      *     rather like "this" in C++ code.
-      * @param sb
-      *     The string buffer to print into.
-      * @param errnum
-      *     The error number that caused all this, obtained from the
-      *     global errno variable, possibly indirectly.
-      * @param fildes
-      *     The original fildes, exactly as passed to the ioctl(2) system call.
-      * @param request
-      *     The original request, exactly as passed to the ioctl(2) system call.
-      * @param data
-      *     The original data, exactly as passed to the ioctl(2) system call.
+      * The print_explanation member is a pointer to a function that
+      * is used to print an representation of the data returned by
+      * a successful ioctl(2) system call.
       */
-    void (*print_explanation)(const explain_iocontrol_t *p,
-        struct explain_string_buffer_t *sb, int errnum, int fildes,
-        int request, const void *data);
+    expain_iocontrol_print_func_t print_explanation;
 
     /**
       * The print_data_returned method is used to print a representation
@@ -158,6 +134,16 @@ struct explain_iocontrol_t
         struct explain_string_buffer_t *sb, int errnum, int fildes,
         int request, const void *data);
 
+    /**
+      * The data_size member is used to remember the sizeof the data
+      * pointed to by the ioctl data argument.  This is used by ioctl
+      * scan to allocate data of the correct size.
+      *
+      * If set to NOT_A_POINTER, it means that the data passed to the ioctl
+      * is not a pointer (an intptr_t instead).
+      */
+    unsigned data_size;
+
     /**
       * The file member is used to rememebr the name of the file this
       * ioctl is defined in, by using __FILE__ in the initialiser.
@@ -323,6 +309,14 @@ int explain_iocontrol_disambiguate_is_a_socket(int fildes, int request,
 int explain_iocontrol_disambiguate_is_not_a_socket(int fildes, int request,
     const void *data);
 
+/**
+  * For use by individual ioctl handlers, a disambiguation that reports
+  * failure (-1) for almost everything, and success (0) for "eql"
+  * network devices.
+  */
+int explain_iocontrol_disambiguate_is_if_eql(int fildes, int request,
+    const void *data);
+
 /**
   * The explain_iocontrol_check_conflicts function is sued to verify
   * that there are no un-expected ioctl request number conflicts.
@@ -330,4 +324,11 @@ int explain_iocontrol_disambiguate_is_not_a_socket(int fildes, int request,
   */
 void explain_iocontrol_check_conflicts(void);
 
+/**
+  * The NOT_A_POINTER value is assigned to an iocontrol::data_size
+  * member to indicate that a given ioctl does not take a pointer
+  * argument.
+  */
+#define NOT_A_POINTER (unsigned)(-1)
+
 #endif /* LIBEXPLAIN_IOCONTROL_H */
