@@ -1,21 +1,22 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 3 of the License, or (at your
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or (at your
  * option) any later version.
  *
- * This program is distributed in the hope that it will be useful,but
- * WITHOUT ANY WARRANTY; without even the implied warranty
- * ofMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNULesser
- * General Public License for more details.
+ * This program is distributed in the hope that it will be useful,but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * for more details.
  *
- * You should have received a copy of the GNU General Public License along
- * with this program. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/sys/ioctl.h>
 #include <libexplain/ac/termios.h>
 
 #include <libexplain/iocontrol/tcsetsf.h>
@@ -46,7 +47,7 @@ const explain_iocontrol_t explain_iocontrol_tcsetsf =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
-    0, /* data_size */
+    sizeof(struct termios), /* data_size */
     __FILE__,
     __LINE__,
 };
