@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -16,13 +16,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/stdio.h>
-#include <libexplain/ac/stdlib.h>
 #include <libexplain/ac/sys/socket.h>
 
 #include <libexplain/listen.h>
-#include <libexplain/option.h>
-#include <libexplain/wrap_and_print.h>
+#include <libexplain/output.h>
 
 
 void
@@ -30,6 +27,6 @@ explain_listen_or_die(int fildes, int backlog)
 {
     if (explain_listen_on_error(fildes, backlog) < 0)
     {
-        exit(EXIT_FAILURE);
+        explain_output_exit_failure();
     }
 }
