@@ -1,36 +1,34 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <libexplain/ac/errno.h>
+#include <libexplain/ac/unistd.h>
 
 #include <libexplain/truncate.h>
 
 
 void
-explain_message_truncate(char *message, int message_size,
-    const char *pathname, long long length)
+explain_message_truncate(char *message, int message_size, const char *pathname,
+    off_t length)
 {
-    explain_message_errno_truncate
-    (
-        message,
-        message_size,
-        errno,
-        pathname,
-        length
-    );
+    explain_message_errno_truncate(message, message_size, errno, pathname,
+        length);
 }
+
+
+/* vim: set ts=8 sw=4 et */
