@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -17,6 +17,8 @@
  */
 
 #include <libexplain/ac/errno.h>
+#include <libexplain/ac/sys/types.h>
+#include <libexplain/ac/ustat.h>
 
 #include <libexplain/ustat.h>
 
