@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -16,11 +16,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/errno.h>
 #include <libexplain/ac/stdio.h>
 
 #include <libexplain/putc.h>
 #include <libexplain/option.h>
-#include <libexplain/wrap_and_print.h>
+#include <libexplain/output.h>
 
 
 #if __GNUC__ < 3
@@ -30,8 +31,12 @@ static
 void
 explain_putc_on_error_failed(int c, FILE *fp)
 {
+    int             hold_errno;
+
+    hold_errno = errno;
     explain_program_name_assemble_internal(1);
-    explain_wrap_and_print(stderr, explain_putc(c, fp));
+    explain_output_message(explain_errno_putc(hold_errno, c, fp));
+    errno = hold_errno;
 }
 
 
