@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -17,11 +17,9 @@
  */
 
 #include <libexplain/ac/stdio.h>
-#include <libexplain/ac/stdlib.h>
 
-#include <libexplain/option.h>
 #include <libexplain/putc.h>
-#include <libexplain/wrap_and_print.h>
+#include <libexplain/output.h>
 
 
 #if __GNUC__ < 3
@@ -32,7 +30,7 @@ void
 explain_putc_or_die_failed(int c, FILE *fp)
 {
     explain_putc_on_error_failed(c, fp);
-    exit(EXIT_FAILURE);
+    explain_output_exit_failure();
 }
 
 
