@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,6 +32,6 @@ explain_string_buffer_puts(explain_string_buffer_t *sb, const char *s)
         return;
     end = sb->message + sb->maximum;
     cp = sb->message + sb->position;
-    cp = strendcpy(cp, s, end);
+    cp = explain_strendcpy(cp, s, end);
     sb->position = cp - sb->message;
 }
