@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -16,8 +16,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/stdlib.h>
+#include <libexplain/ac/sys/types.h>
+#include <libexplain/ac/ustat.h>
 
+#include <libexplain/output.h>
 #include <libexplain/ustat.h>
 
 
@@ -26,7 +28,7 @@ explain_ustat_or_die(dev_t dev, struct ustat *ubuf)
 {
     if (explain_ustat_on_error(dev, ubuf) < 0)
     {
-        exit(EXIT_FAILURE);
+        explain_output_exit_failure();
     }
 }
 
