@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # libexplain - Explain errno values returned by libc functions
-# Copyright (C) 2008, 2009 Peter Miller
+# Copyright (C) 2008-2010 Peter Miller
 # Written by Peter Miller <pmiller@opensource.org.au>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -21,13 +21,19 @@
 TEST_SUBJECT="fputc ENOSPC"
 . test_prelude
 
-cat > test.ok << 'fubar'
+fmt > test.ok.1 << 'fubar'
 fputc(c = '\n', fp = stdout) failed, No space left on device (ENOSPC)
 because the file system containing fildes ("/example", 42% full) has no
 more space for data
 fubar
 test $? -eq 0 || no_result
 
+fmt > test.ok.2 << 'fubar'
+fputc(c = '\n', fp = stdout) failed, No space left on device (ENOSPC)
+because the file system containing fildes has no more space for data
+fubar
+test $? -eq 0 || no_result
+
 explain -e ENOSPC fputc 0x0A > test.out4
 test $? -eq 0 || fail
 
@@ -43,7 +49,9 @@ test $? -eq 0 || no_result
 fmt test.out2 > test.out
 test $? -eq 0 || no_result
 
-diff test.ok test.out
+diff test.ok.2 test.out > /dev/null 2> /dev/null && pass
+
+diff test.ok.1 test.out
 test $? -eq 0 || fail
 
 #
