@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # libexplain - Explain errno values returned by libc functions
-# Copyright (C) 2009 Peter Miller
+# Copyright (C) 2009, 2010 Peter Miller
 # Written by Peter Miller <pmiller@opensource.org.au>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -22,20 +22,22 @@ TEST_SUBJECT="getsockname EFAULT"
 . test_prelude
 
 fmt > test.ok << 'fubar'
-getsockname(fildes = 42, sock_addr = 0xNNNNNNNN, sock_addr_size = { 128
-}) failed, Bad address (EFAULT) because sock_addr refers to memory that
+getsockname(fildes = 42, sock_addr = 0xNNNNNNNN, sock_addr_size = { XXX })
+failed, Bad address (EFAULT) because sock_addr refers to memory that
 is outside the process's accessible address space; this is more likely
 to be a software error (a bug) than it is to be a user error
 fubar
 test $? -eq 0 || no_result
 
-explain -e EFAULT getsockname 42 0x12345 128 > test.out.4
+explain -e EFAULT getsockname 42 0x9876543 128 > test.out.4
 test $? -eq 0 || fail
 
 fmt -w700 test.out.4 > test.out.3
 test $? -eq 0 || no_result
 
-sed 's|sock_addr = [^,)]*|sock_addr = 0xNNNNNNNN|' < test.out.3 > test.out.2
+sed -e 's|0x[0-9a-fA-F][A-Fa-f0-9]*|0xNNNNNNNN|g' \
+    -e 's|size = { [0-9]* }|size = { XXX }|g' \
+    test.out.3 > test.out.2
 test $? -eq 0 || no_result
 
 fmt test.out.2 > test.out
